@@ -1,6 +1,6 @@
 CREATE TABLE WWWUSAGE (
 	VHOST	VARCHAR(128) NOT NULL,
 	LDATE   INT(8) UNSIGNED NOT NULL,
-	BYTES	INT(32) UNSIGNED NOT NULL DEFAULT '0',
+	BYTES	INT(32) UNSIGNED NOT NULL DEFAULT '0'
 );
 
